@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Document.py,v 1.18.2.5 2000/07/24 09:39:32 fredgo Exp $
+# $Id: Document.py,v 1.18.2.9 2000/11/13 09:35:25 fredgo Exp $
 
 ''' This module defines a Document class '''
 
@@ -36,7 +36,7 @@ from Pyblio import version, Fields, Types
 
 import Pyblio.Style.Utils
 
-import gettext, os, string, copy, types, sys, traceback
+import gettext, os, string, copy, types, sys, traceback, stat
 
 _ = gettext.gettext
 
@@ -167,7 +167,9 @@ class Document (Connector.Publisher):
         self.lyx       = None
         self.changed   = 0
         self.directory = None
-        
+
+        self.modification_date = None
+
         self.redisplay_index ()
         return
 
@@ -233,7 +235,13 @@ class Document (Connector.Publisher):
         entries = map (lambda x: x.key, self.index.selection ())
         
         if not entries:
-            entries = self.data.keys ()
+            iter    = self.selection.iterator (self.data.iterator ())
+            entries = []
+            
+            e = iter.first ()
+            while e:
+                entries.append (e.key)
+                e = iter.next ()
 
         url = Fields.URL (style)
 
@@ -389,12 +397,23 @@ class Document (Connector.Publisher):
         # eventually warn interested objects
         self.issue ('open-document', self)
         return
+
     
     def save_document (self, * arg):
         if self.data.key is None:
             self.save_document_as ()
             return
 
+        file = self.data.key.url [2]
+        
+        if self.modification_date:
+            mod_date = os.stat (file) [stat.ST_MTIME]
+            
+            if mod_date > self.modification_date:
+                if not Utils.Callback (_("The database has been externally modified.\nOverwrite changes ?"),
+                                       self.w).answer ():
+                    return
+        
         Utils.set_cursor (self.w, 'clock')
         try:
             try:
@@ -414,6 +433,9 @@ class Document (Connector.Publisher):
 
         Utils.set_cursor (self.w, 'normal')
 
+        # get the current modification date
+        self.modification_date = os.stat (file) [stat.ST_MTIME]
+        
         self.update_status (0)
         return
     
@@ -649,7 +671,14 @@ class Document (Connector.Publisher):
     
 
     def sort_by_field (self, field):
-        self.selection.sort = Sort.Sort ([Sort.FieldSort (field)])
+        if field == '-key-':
+            mode = Sort.KeySort ()
+        elif field == '-type-':
+            mode = Sort.TypeSort ()
+        else:
+            mode = Sort.FieldSort (field)
+            
+        self.selection.sort = Sort.Sort ([mode])
         self.redisplay_index ()
         return
 
@@ -700,8 +729,10 @@ class Document (Connector.Publisher):
 
         # updates the index's config
         self.index.update_configuration ()
-        
-        config.sync ()
+
+        # ...and the search window
+        if self.search_dg:
+            self.search_dg.update_configuration ()
         return
 
     
