@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: reverse.c,v 1.8.2.1 2000/10/09 07:26:21 fredgo Exp $
+ $Id: reverse.c,v 1.8.2.3 2000/11/21 16:24:41 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -177,21 +177,35 @@ bibtex_reverse_field (BibtexField * field,
 	    g_string_append (st, "@preamble{\"");
 	}
 
-	/* Put the upper cases or the first lower cases between {} */
+	/* Put the first lower case between {} */
 	string = tmp;
 	if (* tmp >= 'a' && * tmp <= 'z') {
 	    /* Put the beginning in lower cases */
 	    g_string_append_c (st, '{');
 	    g_string_append_c (st, * tmp);
 	    g_string_append_c (st, '}');
-	    tmp ++;
 	}
+	else {
+	    /* The first character is done */
+	    g_string_append_c (st, * tmp);
+	}
+	
+	tmp ++;
 
+	/* check for upper cases afterward */
 	is_upper   = false;
 	is_command = false;
 
 	while (* tmp) {
+	    /* start a latex command */
 	    if (* tmp == '\\') {
+
+		/* eventually closes the bracket */
+		if (is_upper) {
+		    is_upper = false;
+		    g_string_append_c (st, '}');
+		}
+
 		is_command = true;
 		g_string_append_c (st, * tmp);
 		tmp ++;
@@ -209,7 +223,7 @@ bibtex_reverse_field (BibtexField * field,
 		continue;
 	    }
 
-	    if (* tmp >= 'A' && * tmp <= 'Z' && (tmp > string)) {
+	    if (* tmp >= 'A' && * tmp <= 'Z') {
 		if (! is_upper) {
 		    g_string_append_c (st, '{');
 		    is_upper = true;
@@ -226,6 +240,8 @@ bibtex_reverse_field (BibtexField * field,
 	    }
 	    tmp ++;
 	}
+
+	/* eventually close the brackets */
 	if (is_upper) {
 	    g_string_append_c (st, '}');
 	    is_upper = false;
